/*
 * Asterisk -- An open source telephony toolkit.
 *
 * Copyright (C) 2006, Digium, Inc.
 *
 * See http://www.asterisk.org for more information about
 * the Asterisk project. Please do not directly contact
 * any of the maintainers of this project for assistance;
 * the project provides a web site, mailing lists and IRC
 * channels for your use.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 */

/*! \file
 *
 * \brief Determine whether extension exists or not
 * 
 * \author David Chappell <David.Chappell@trincoll.edu>
 */

#include "asterisk.h"

ASTERISK_FILE_VERSION(__FILE__, "$Revision: 45143 $")

#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <sys/types.h>

#include "asterisk/module.h"
#include "asterisk/channel.h"
#include "asterisk/pbx.h"
#include "asterisk/logger.h"
#include "asterisk/utils.h"
#include "asterisk/app.h"

static int acf_isexten_exec(struct ast_channel *chan, char *cmd,
			 char *parse, char *buffer, size_t buflen)
{
	struct ast_module_user *u;
	int response_int, priority_int;
	AST_DECLARE_APP_ARGS(args,
			     AST_APP_ARG(context);
			     AST_APP_ARG(extension);
			     AST_APP_ARG(priority);
	);

	u = ast_module_user_add(chan);

	AST_STANDARD_APP_ARGS(args, parse);

	if (ast_strlen_zero(args.context))
		args.context = chan->context;

	if (ast_strlen_zero(args.extension)) {
		ast_log(LOG_WARNING, "Syntax: ISEXTEN(<context>,<extension>[,<priority>]) - missing argument <extension>!\n");
		return -1;
	}

	if (ast_strlen_zero(args.priority))
		priority_int = 1;
	else
		priority_int = atoi(args.priority);

	if (ast_exists_extension(chan, args.context, args.extension, priority_int, chan->cid.cid_num))
	    ast_copy_string(buffer, "1", buflen);
	else
	    ast_copy_string(buffer, "0", buflen);

	ast_module_user_remove(u);

	return 0;
}

static struct ast_custom_function acf_isexten = {
	.name = "ISEXTEN",
	.synopsis = "Determine whether an extension exists or not",
	.syntax = "ISEXTEN(context,extension[,priority])",
	.desc =
		"  Returns a true value if the indicated context, extension, and priority exist.\n"
		"  If priority is omitted, it will be understood to be 1.\n",
	.read = acf_isexten_exec,
};

static int unload_module(void)
{
	ast_custom_function_unregister(&acf_isexten);

	return 0;
}

static int load_module(void)
{
	return ast_custom_function_register(&acf_isexten);
}

AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "ISEXTEN dialplan function");
